@@ -38,12 +38,35 @@ import devedeng.vcdimager_converter
 import devedeng.shutdown
 import devedeng.about
 import devedeng.opensave
+import devedeng.help
+
 
 class devede_project:
 
+    dvd_max_bps_base = {0: 9000}
+    dvd_min_bps = 300
+    dvd_max_total = 10000
+
+    svcd_max_bps_base = {0: 2700}
+    svcd_min_bps = 200
+    svcd_max_total = 2700
+
+    divx_max_bps_base = {0: 4854, 720: 9708, 1080: 20000}
+    divx_min_bps = 300
+    divx_max_total = -1
+
+    mkv_max_bps_base = {0: 192, 240: 2000,
+                        480: 14000,  720: 50000, 1080: 240000}
+    mkv_min_bps = 192
+    mkv_max_total = -1
+
+    def_max_bps_base = {0: 9000}
+    def_min_bps = 300
+    def_max_total = -1
+
     def __init__(self):
 
-        self.config  = devedeng.configuration_data.configuration.get_config()
+        self.config = devedeng.configuration_data.configuration.get_config()
 
         self.disc_type = self.config.disc_type
         self.menu = devedeng.dvd_menu.dvd_menu()
@@ -54,7 +77,7 @@ class devede_project:
         builder = Gtk.Builder()
         builder.set_translation_domain(self.config.gettext_domain)
 
-        builder.add_from_file(os.path.join(self.config.glade,"wmain.ui"))
+        builder.add_from_file(os.path.join(self.config.glade, "wmain.ui"))
         builder.connect_signals(self)
 
         # Interface widgets
@@ -67,11 +90,12 @@ class devede_project:
         self.wuse_ntsc = builder.get_object("use_ntsc")
         self.wframe_titles = builder.get_object("frame_titles")
 
+        self.winmenu = builder.get_object("treeviewcolumn3")
+
         self.wframe_menu = builder.get_object("frame_menu")
         self.wcreate_menu = builder.get_object("create_menu")
         self.wmenu_options = builder.get_object("menu_options")
 
-
         self.wadd_file = builder.get_object("add_file")
         self.wdelete_file = builder.get_object("delete_file")
         self.wup_file = builder.get_object("up_file")
@@ -93,48 +117,48 @@ class devede_project:
 
         self.wcreate_menu.set_active(True)
 
-        self.config.connect('disc_type',self.set_type)
-        if (self.disc_type != None):
+        self.config.connect('disc_type', self.set_type)
+        if (self.disc_type is not None):
             self.set_type(None, self.disc_type)
 
-        self.wmain_window.drag_dest_set(Gtk.DestDefaults.ALL,[],Gdk.DragAction.COPY)
+        self.wmain_window.drag_dest_set(
+            Gtk.DestDefaults.ALL, [], Gdk.DragAction.COPY)
         targets = Gtk.TargetList.new([])
-        targets.add(Gdk.Atom.intern("text/uri-list", False),0,0)
+        targets.add(Gdk.Atom.intern("text/uri-list", False), 0, 0)
         self.wmain_window.drag_dest_set_target_list(targets)
 
-
-    def set_type(self,obj=None,disc_type=None):
+    def set_type(self, obj=None, disc_type=None):
         """ this method sets the disk type to the specified one and adapts the interface
-            in the main window to it. Also leaves everything ready to start creating a
-            new disc """
+                in the main window to it. Also leaves everything ready to start creating a
+                new disc """
 
-        if (disc_type != None):
+        if (disc_type is not None):
             self.disc_type = disc_type
         self.wmain_window.show_all()
         self.set_interface_status(None)
 
         # Set the default disc size
         if (self.disc_type == "dvd") or (self.disc_type == "mkv"):
-            self.wdisc_size.set_active(1) # 4.7 GB DVD
+            self.wdisc_size.set_active(1)  # 4.7 GB DVD
         else:
-            self.wdisc_size.set_active(3) # 700 MB CD
+            self.wdisc_size.set_active(3)  # 700 MB CD
 
         if (self.disc_type == "dvd"):
+            self.winmenu.set_visible(True)
             self.wframe_menu.show_all()
             self.wcreate_menu.set_active(True)
         else:
+            self.winmenu.set_visible(False)
             self.wframe_menu.hide()
             self.wcreate_menu.set_active(False)
 
-
     def get_current_file(self):
-
         """ returns the currently selected file """
 
         selection = self.wfiles.get_selection()
         model, treeiter = selection.get_selected()
 
-        if treeiter != None:
+        if treeiter is not None:
             element = model[treeiter][0]
             position = 0
             for row in self.wfiles.get_model():
@@ -142,10 +166,9 @@ class devede_project:
                 if element == item:
                     break
                 position += 1
-            return ( (element, position, model, treeiter) )
+            return ((element, position, model, treeiter))
         else:
-            return ( (None, -1, None, None) )
-
+            return ((None, -1, None, None))
 
     def get_all_files(self):
 
@@ -155,8 +178,7 @@ class devede_project:
             retval.append(row.model[row.iter][0])
         return retval
 
-
-    def set_interface_status(self,b):
+    def set_interface_status(self, b):
 
         self.wadd_file.set_sensitive(True)
         self.wdelete_file.set_sensitive(True)
@@ -171,7 +193,7 @@ class devede_project:
         self.pal = self.wuse_pal.get_active()
 
         (element, position, model, treeiter) = self.get_current_file()
-        if (element == None):
+        if (element is None):
             self.wdelete_file.set_sensitive(False)
             self.wup_file.set_sensitive(False)
             self.wdown_file.set_sensitive(False)
@@ -183,58 +205,71 @@ class devede_project:
                 self.wdelete_file.set_sensitive(False)
             if (position == 0):
                 self.wup_file.set_sensitive(False)
-            if (position == (nfiles-1)):
+            if (position == (nfiles - 1)):
                 self.wdown_file.set_sensitive(False)
 
-
     def on_cellrenderertext3_edited(self, widget, path, text):
         self.wliststore_files[path][0].set_title(text)
 
+    def on_cellrenderertext4_toggled(self, widget, path):
+        self.wliststore_files[path][0].set_show_in_menu(
+            False if widget.get_active() else True)
 
-    def on_use_pal_toggled(self,b):
+    def on_use_pal_toggled(self, b):
 
         self.config.PAL = self.wuse_pal.get_active()
         self.set_interface_status(None)
 
-
-    def on_wmain_window_delete_event(self,b,e=None):
+    def on_wmain_window_delete_event(self, b, e=None):
 
         ask = devedeng.ask.ask_window()
-        if (ask.run(_("Abort the current DVD and exit?"),_("Exit DeVeDe"))):
+        if (ask.run(_("Abort the current DVD and exit?"), _("Exit DeVeDe"))):
             Gtk.main_quit()
         return True
 
-    def title_changed(self,obj,new_title):
+    def title_changed(self, obj, new_title):
 
         for item in self.wliststore_files:
             element = item.model[item.iter][0]
             if element == obj:
-                item.model.set_value(item.iter,1,new_title)
+                item.model.set_value(item.iter, 1, new_title)
         self.refresh_disc_usage()
 
+    def in_menu_changed(self, obj, new_inmenu):
+        for item in self.wliststore_files:
+            element = item.model[item.iter][0]
+            if element == obj:
+                item.model.set_value(item.iter, 4, new_inmenu)
+        self.refresh_disc_usage()
 
-    def on_add_file_clicked(self,b):
+    def on_help_clicked(self, b):
+
+        help_file = devedeng.help.help("main.html")
+
+    def on_help_index_activate(self, b):
+
+        help_file = devedeng.help.help("index.html")
+
+    def on_add_file_clicked(self, b):
 
         ask_files = devedeng.add_files.add_files()
         if (ask_files.run()):
             self.add_several_files(ask_files.files)
 
+    def duration_to_string(self, duration):
 
-    def duration_to_string(self,duration):
+        seconds = math.floor(duration % 60)
+        minutes = math.floor((duration / 60) % 60)
+        hours = math.floor(duration / 3600)
 
-        seconds = math.floor(duration%60)
-        minutes = math.floor((duration/60)%60)
-        hours = math.floor(duration/3600)
-
-        output = str(seconds)+"s"
+        output = str(seconds) + "s"
         if ((hours != 0) or (minutes != 0)):
-            output = str(minutes)+"m "+output
+            output = str(minutes) + "m " + output
         if (hours != 0):
-            output = str(hours)+"h "+output
+            output = str(hours) + "h " + output
         return output
 
-
-    def add_several_files(self,file_list):
+    def add_several_files(self, file_list):
         error_list = []
         for efile in file_list:
             if efile.startswith("file://"):
@@ -243,63 +278,60 @@ class devede_project:
             if (new_file.error):
                 error_list.append(os.path.basename(efile))
             else:
-                new_file.connect('title_changed',self.title_changed)
-                self.wliststore_files.append([new_file, new_file.title_name,True,self.duration_to_string(new_file.get_duration())])
-        if (len(error_list)!=0):
-            devedeng.message.message_window(_("The following files could not be added:"),_("Error while adding files"),error_list)
+                new_file.connect('title_changed', self.title_changed)
+                new_file.connect('in_menu_changed', self.in_menu_changed)
+                self.wliststore_files.append([new_file, new_file.title_name, True, self.duration_to_string(
+                    new_file.get_duration()), new_file.show_in_menu])
+        if (len(error_list) != 0):
+            devedeng.message.message_window(_("The following files could not be added:"), _(
+                "Error while adding files"), error_list)
         self.set_interface_status(None)
         self.refresh_disc_usage()
 
-
-    def on_delete_file_clicked(self,b):
+    def on_delete_file_clicked(self, b):
 
         (element, position, model, treeiter) = self.get_current_file()
-        if (element == None):
+        if (element is None):
             return
 
         ask_w = devedeng.ask.ask_window()
-        if (ask_w.run(_("The file <b>%(X)s</b> <i>(%(Y)s)</i> will be removed.") % {"X":element.title_name, "Y":element.file_name},_("Delete file"))):
+        if (ask_w.run(_("The file <b>%(X)s</b> <i>(%(Y)s)</i> will be removed.") % {"X": element.title_name, "Y": element.file_name}, _("Delete file"))):
             element.delete_file()
             model.remove(treeiter)
             self.set_interface_status(None)
             self.refresh_disc_usage()
 
-
-    def on_up_file_clicked(self,b):
+    def on_up_file_clicked(self, b):
 
         (element, position, model, treeiter) = self.get_current_file()
-        if (element == None) or (position == 0):
+        if (element is None) or (position == 0):
             return
 
-        last_element = self.wfiles.get_model()[position-1]
-        self.wfiles.get_model().swap(last_element.iter,treeiter)
+        last_element = self.wfiles.get_model()[position - 1]
+        self.wfiles.get_model().swap(last_element.iter, treeiter)
         self.set_interface_status(None)
 
-
-    def on_down_file_clicked(self,b):
+    def on_down_file_clicked(self, b):
 
         (element, position, model, treeiter) = self.get_current_file()
-        if (element == None) or (position == (len(self.wfiles.get_model())-1)):
+        if (element is None) or (position == (len(self.wfiles.get_model()) - 1)):
             return
 
-        last_element = self.wfiles.get_model()[position+1]
-        self.wfiles.get_model().swap(last_element.iter,treeiter)
+        last_element = self.wfiles.get_model()[position + 1]
+        self.wfiles.get_model().swap(last_element.iter, treeiter)
         self.set_interface_status(None)
 
-
-    def on_properties_file_clicked(self,b):
+    def on_properties_file_clicked(self, b):
         (element, position, model, treeiter) = self.get_current_file()
-        if (element == None):
+        if (element is None):
             return
         element.properties()
 
-
-    def on_create_menu_toggled(self,b):
+    def on_create_menu_toggled(self, b):
         self.set_interface_status(None)
         self.refresh_disc_usage()
 
-
-    def on_adjust_disc_usage_clicked(self,b):
+    def on_adjust_disc_usage_clicked(self, b):
 
         total_resolution = 0
         fixed_size = 0
@@ -311,36 +343,38 @@ class devede_project:
             else:
                 fixed_size += ((audio_rate + sub_rate) * time_length)
                 # 76800 = 320x240, which is the smallest resolution
-                surface = ((float(width) * float(height)) / 76800.0) * float(time_length)
-                to_adjust.append( (f, surface, time_length, audio_rate, height) )
+                surface = ((float(width) * float(height)) /
+                           76800.0) * float(time_length)
+                to_adjust.append((f, surface, time_length, audio_rate, height))
                 total_resolution += surface
 
         if (self.disc_type == "dvd") and (self.wcreate_menu.get_active()):
             fixed_size += self.menu.get_estimated_size() * 8.0
 
         if (self.disc_type == "dvd"):
-            max_bps_base = {0: 9000}
-            min_bps = 300
-            max_total = 10000
+            max_bps_base = devede_project.dvd_max_bps_base.copy()
+            min_bps = devede_project.dvd_min_bps
+            max_total = devede_project.dvd_max_total
         elif (self.disc_type == "svcd") or (self.disc_type == "cvd"):
-            max_bps_base = {0: 2700}
-            min_bps = 200
-            max_total = 2700
+            max_bps_base = devede_project.svcd_max_bps_base.copy()
+            min_bps = devede_project.svcd_min_bps
+            max_total = devede_project.svcd_max_total
         elif (self.disc_type == "divx"):
-            max_bps_base = {0: 4854, 720: 9708, 1080: 20000}
-            min_bps = 300
-            max_total = -1
+            max_bps_base = devede_project.divx_max_bps_base.copy()
+            min_bps = devede_project.divx_min_bps
+            max_total = devede_project.divx_max_total
         elif (self.disc_type == "mkv"):
-            max_bps_base = {0: 192, 240: 2000, 480: 14000,  720: 50000, 1080: 240000}
-            min_bps = 192
-            max_total = -1
+            max_bps_base = devede_project.mkv_max_bps_base.copy()
+            min_bps = devede_project.mkv_min_bps
+            max_total = devede_project.mkv_max_total
         else:
-            max_bps_base = {0: 9000}
-            min_bps = 300
-            max_total = -1
+            max_bps_base = devede_project.def_max_bps_base.copy()
+            min_bps = devede_project.def_min_bps
+            max_total = devede_project.def_max_total
 
         if (total_resolution != 0):
-            remaining_disc_size = ((8000.0 * self.get_dvd_size()[0]) - fixed_size) # in kbits
+            remaining_disc_size = (
+                (8000.0 * self.get_dvd_size()[0]) - fixed_size)  # in kbits
             for l in to_adjust:
                 f = l[0]
                 surface = l[1]
@@ -355,7 +389,8 @@ class devede_project:
                         resy = bitrates
                         max_bps = max_bps_base[bitrates]
 
-                video_rate = (remaining_disc_size * surface) / ( length * total_resolution)
+                video_rate = (remaining_disc_size * surface) / \
+                    (length * total_resolution)
                 if max_total != -1:
                     max2 = max_total - audio_rate
                     if (max2 > max_bps):
@@ -370,7 +405,6 @@ class devede_project:
 
         self.refresh_disc_usage()
 
-
     def refresh_disc_usage(self):
 
         used = 0.0
@@ -384,74 +418,70 @@ class devede_project:
 
         used /= 1000.0
 
-        disc_size,minvrate,maxvrate = self.get_dvd_size()
+        disc_size, minvrate, maxvrate = self.get_dvd_size()
 
         if used > disc_size:
             self.wdisc_fill_level.set_fraction(1.0)
-            addv=1
+            addv = 1
         else:
             self.wdisc_fill_level.set_fraction(used / disc_size)
-            addv=0
+            addv = 0
 
-        self.wdisc_fill_level.set_text(str(addv+int((used / disc_size)*100))+"%")
+        self.wdisc_fill_level.set_text(
+            str(addv + int((used / disc_size) * 100)) + "%")
         self.wdisc_fill_level.set_show_text(True)
 
-
-    def on_menu_options_clicked(self,b):
+    def on_menu_options_clicked(self, b):
 
         self.menu.show_configuration(self.get_all_files())
 
-
     def get_dvd_size(self):
-
         """ Returns the size for the currently selected disk type, and the minimum and maximum
-            videorate for the current video disk """
+                videorate for the current video disk """
 
         active = self.wdisc_size.get_active()
 
         # here we choose the size in Mbytes for the media
-        if 5==active:
-            size=170.0
-        elif 4==active:
-            size=700.0
-        elif 3==active:
-            size=750.0
-        elif 2==active:
-            size=1100.0
-        elif 1==active:
-            size=4200.0
+        if 5 == active:
+            size = 170.0
+        elif 4 == active:
+            size = 700.0
+        elif 3 == active:
+            size = 750.0
+        elif 2 == active:
+            size = 1100.0
+        elif 1 == active:
+            size = 4200.0
         else:
-            size=8000.0
+            size = 8000.0
 
-        if self.disc_type=="vcd":
-            minvrate=1152
-            maxvrate=1152
+        if self.disc_type == "vcd":
+            minvrate = 1152
+            maxvrate = 1152
         elif (self.disc_type == "svcd") or (self.disc_type == "cvd"):
-            minvrate=400
-            maxvrate=2300
+            minvrate = 400
+            maxvrate = 2300
         elif (self.disc_type == "dvd"):
-            minvrate=400
-            maxvrate=8500
+            minvrate = 400
+            maxvrate = 8500
         elif (self.disc_type == "divx") or (self.disc_type == "mkv"):
-            minvrate=300
-            maxvrate=6000
+            minvrate = 300
+            maxvrate = 6000
         else:
             minvrate = 0
             maxvrate = 8000
 
         size *= 0.90  # a safe margin of 10% to ensure that it never will be bigger
-                    # (it's important to have in mind the space needed by disk structures like
-                    # directories, file entries, and so on)
+        # (it's important to have in mind the space needed by disk structures like
+        # directories, file entries, and so on)
 
-        return size,minvrate,maxvrate
+        return size, minvrate, maxvrate
 
-
-    def on_disc_size_changed(self,c):
+    def on_disc_size_changed(self, c):
 
         self.refresh_disc_usage()
 
-
-    def on_create_disc_clicked(self,b):
+    def on_create_disc_clicked(self, b):
 
         if self.disc_type == "dvd":
             max_files = 62
@@ -461,7 +491,8 @@ class devede_project:
         file_movies = self.get_all_files()
         t = len(file_movies)
         if (max_files != -1) and (t > max_files):
-            devedeng.message.message_window(_("The limit for this format is %(l)d files, but your project has %(h)d.") % {"l": max_files, "h" : t}, _("Too many files in the project"))
+            devedeng.message.message_window(_("The limit for this format is %(l)d files, but your project has %(h)d.") % {
+                                            "l": max_files, "h": t}, _("Too many files in the project"))
             return
 
         data = devedeng.create_disk_window.create_disk_window()
@@ -470,25 +501,25 @@ class devede_project:
 
         if os.path.exists(data.path):
             ask_w = devedeng.ask.ask_window()
-            retval = ask_w.run(_("The selected folder already exists. To create the project, Devede must delete it.\nIf you continue, the folder\n\n <b>%s</b>\n\n and all its contents <b>will be deleted</b>. Continue?") % data.path,_("Delete folder"))
+            retval = ask_w.run(_("The selected folder already exists. To create the project, Devede must delete it.\nIf you continue, the folder\n\n <b>%s</b>\n\n and all its contents <b>will be deleted</b>. Continue?") % data.path, _("Delete folder"))
             if retval:
                 # delete only the bare minimun needed
-                shutil.rmtree(os.path.join(data.path,"dvd_tree"),True)
-                shutil.rmtree(os.path.join(data.path,"menu"),True)
-                shutil.rmtree(os.path.join(data.path,"movies"),True)
-                shutil.rmtree(os.path.join(data.path,"xml_data"),True)
+                shutil.rmtree(os.path.join(data.path, "dvd_tree"), True)
+                shutil.rmtree(os.path.join(data.path, "menu"), True)
+                shutil.rmtree(os.path.join(data.path, "movies"), True)
+                shutil.rmtree(os.path.join(data.path, "xml_data"), True)
                 if self.config.disc_type == "dvd":
                     try:
-                        os.unlink(os.path.join(data.path,data.name+".iso"))
+                        os.unlink(os.path.join(data.path, data.name + ".iso"))
                     except:
                         pass
                 if (self.config.disc_type == "vcd") or (self.config.disc_type == "svcd") or (self.config.disc_type == "cvd"):
                     try:
-                        os.unlink(os.path.join(data.path,data.name+".bin"))
+                        os.unlink(os.path.join(data.path, data.name + ".bin"))
                     except:
                         pass
                     try:
-                        os.unlink(os.path.join(data.path,data.name+".cue"))
+                        os.unlink(os.path.join(data.path, data.name + ".cue"))
                     except:
                         pass
             else:
@@ -501,21 +532,29 @@ class devede_project:
         final_dependencies = []
 
         if (self.disc_type == "dvd") and (self.wcreate_menu.get_active()):
-            processes,menu_entries = self.menu.create_dvd_menus(file_movies, data.path)
+            processes, menu_entries = self.menu.create_dvd_menus(
+                file_movies, data.path)
             for p in processes:
                 run_window.add_process(p)
                 final_dependencies.append(p)
         else:
             menu_entries = None
 
-        movie_folder = os.path.join(data.path,"movies")
+        movie_folder = os.path.join(data.path, "movies")
         try:
             os.makedirs(movie_folder)
         except:
             pass
         counter = 0
+        if self.disc_type == "divx":
+            extension = "avi"
+        elif self.disc_type == "mkv":
+            extension = "mkv"
+        else:
+            extension = "mpg"
         for movie in file_movies:
-            p = movie.do_conversion(os.path.join(movie_folder,"movie_"+str(counter)+".mpg"))
+            p = movie.do_conversion(os.path.join(
+                movie_folder, "movie_{:d}.{:s}".format(counter, extension)))
             run_window.add_process(p)
             final_dependencies.append(p)
             counter += 1
@@ -526,7 +565,8 @@ class devede_project:
             else:
                 start_with_menu = False
             dvdauthor = devedeng.dvdauthor_converter.dvdauthor_converter()
-            dvdauthor.create_dvd_project(data.path, data.name, file_movies, menu_entries, start_with_menu)
+            dvdauthor.create_dvd_project(
+                data.path, data.name, file_movies, menu_entries, start_with_menu, self.menu.play_all_c)
             # dvdauthor must wait until all the files have been converted
             for element in final_dependencies:
                 dvdauthor.add_dependency(element)
@@ -537,24 +577,23 @@ class devede_project:
             isocreator.create_iso(data.path, data.name)
             isocreator.add_dependency(dvdauthor)
             run_window.add_process(isocreator)
-            self.disc_image_name = os.path.join(data.path,data.name+".iso")
+            self.disc_image_name = os.path.join(data.path, data.name + ".iso")
         elif (self.disc_type == "vcd") or (self.disc_type == "svcd") or (self.disc_type == "cvd"):
             vcdcreator = devedeng.vcdimager_converter.vcdimager_converter()
             vcdcreator.create_cd_project(data.path, data.name, file_movies)
             for element in final_dependencies:
                 vcdcreator.add_dependency(element)
             run_window.add_process(vcdcreator)
-            self.disc_image_name = os.path.join(data.path,data.name+".cue")
+            self.disc_image_name = os.path.join(data.path, data.name + ".cue")
         else:
             self.disc_image_name = None
 
-        run_window.connect("done",self.disc_done)
+        run_window.connect("done", self.disc_done)
         self.wmain_window.hide()
         self.time_start = time.time()
         run_window.run()
 
-
-    def disc_done(self,object,value):
+    def disc_done(self, object, value):
 
         if self.shutdown:
             Gtk.main_quit()
@@ -562,7 +601,7 @@ class devede_project:
 
         if value == 0:
             ended = devedeng.end_job.end_window()
-            if self.disc_image_name == None:
+            if self.disc_image_name is None:
                 do_burn = False
             else:
                 do_burn = True
@@ -578,31 +617,26 @@ class devede_project:
 
         self.wmain_window.show()
 
-
-    def disc_done2(self,object, value):
+    def disc_done2(self, object, value):
 
         self.wmain_window.show()
 
-
-    def on_preview_file_clicked(self,b):
+    def on_preview_file_clicked(self, b):
 
         (element, position, model, treeiter) = self.get_current_file()
-        if (element == None):
+        if (element is None):
             return
         element.do_preview()
 
-
-    def on_settings_activate(self,b):
+    def on_settings_activate(self, b):
 
         w = devedeng.settings.settings_window()
 
-
-    def on_about_activate(self,b):
+    def on_about_activate(self, b):
 
         w = devedeng.about.about_window()
 
-
-    def on_new_activate(self,b):
+    def on_new_activate(self, b):
 
         w = devedeng.ask.ask_window()
         if w.run(_("Close current project and start a fresh one?"), _("New project")):
@@ -611,36 +645,31 @@ class devede_project:
             self.wmain_window.hide()
             devedeng.choose_disc_type.choose_disc_type()
 
-
-    def on_wmain_window_drag_motion(self,wid, context, x, y, time):
+    def on_wmain_window_drag_motion(self, wid, context, x, y, time):
         Gdk.drag_status(context, Gdk.DragAction.COPY, time)
         return True
 
-
     def on_wmain_window_drag_drop(self, wid, context, x, y, time):
         # Used with windows drag and drop
         return True
 
-
-    def on_wmain_window_drag_data_received(self, widget, drag_context, x,y, data, info, time):
+    def on_wmain_window_drag_data_received(self, widget, drag_context, x, y, data, info, time):
         uris = data.get_uris()
         self.add_several_files(uris)
-        Gtk.drag_finish (drag_context, True, Gdk.DragAction.COPY, time);
+        Gtk.drag_finish(drag_context, True, Gdk.DragAction.COPY, time)
 
-
-    def on_save_activate(self,b):
-        if self.project_file != None:
+    def on_save_activate(self, b):
+        if self.project_file is not None:
             self.save_current_project()
         else:
             self.on_save_as_activate(None)
 
-
-    def on_save_as_activate(self,b):
+    def on_save_as_activate(self, b):
 
         while True:
             w = devedeng.opensave.opensave_window(True)
             retval = w.run(self.project_file)
-            if retval == None:
+            if retval is None:
                 return
             if not retval.endswith(".devedeng"):
                 retval += ".devedeng"
@@ -652,14 +681,12 @@ class devede_project:
             self.save_current_project()
             return
 
-
-    def on_load_activate(self,b):
+    def on_load_activate(self, b):
         w = devedeng.opensave.opensave_window(False)
         retval = w.run()
-        if retval != None:
+        if retval is not None:
             self.load_project(retval)
 
-
     def save_current_project(self):
 
         project = {}
@@ -678,8 +705,7 @@ class devede_project:
         with open(self.project_file, 'wb') as f:
             pickle.dump(project, f, 3)
 
-
-    def load_project(self,project_file):
+    def load_project(self, project_file):
 
         self.wliststore_files.clear()
         self.project_file = project_file
@@ -703,15 +729,16 @@ class devede_project:
                     error_list.append(os.path.basename(efile["file_name"]))
                 else:
                     new_file.restore_file(efile)
-                    new_file.connect('title_changed',self.title_changed)
-                    self.wliststore_files.append([new_file, new_file.title_name,True,self.duration_to_string(new_file.get_duration())])
-            if (len(error_list)!=0):
-                devedeng.message.message_window(_("The following files in the project could not be added again:"),_("Error while adding files"),error_list)
+                    new_file.connect('title_changed', self.title_changed)
+                    self.wliststore_files.append([new_file, new_file.title_name, True, self.duration_to_string(
+                        new_file.get_duration()), new_file.show_in_menu])
+            if (len(error_list) != 0):
+                devedeng.message.message_window(_("The following files in the project could not be added again:"), _(
+                    "Error while adding files"), error_list)
         self.set_interface_status(None)
         self.refresh_disc_usage()
 
+    def on_multiproperties_activate(self, b):
 
-    def on_multiproperties_activate(self,b):
-
-        e = devedeng.file_movie.file_movie(None,self.get_all_files())
+        e = devedeng.file_movie.file_movie(None, self.get_all_files())
         e.properties()
